Loss functions
==============

.. automodule:: mumott.optimization.loss_functions

.. index::
   single: Class reference; SquaredLoss
.. autoclass:: mumott.optimization.loss_functions.SquaredLoss
   :members:
   :undoc-members:
   :inherited-members:
